@@ -26,7 +26,6 @@ from collections import OrderedDict
 from decimal import *
 from datetime import timedelta
 
-import six
 from aenum import Enum
 from isodate import parse_duration, duration_isoformat
 
@@ -34,6 +33,7 @@ from gremlin_python import statics
 from gremlin_python.statics import FloatType, FunctionType, IntType, LongType, TypeType, SingleByte, ByteBufferType, SingleChar
 from gremlin_python.process.traversal import Binding, Bytecode, P, TextP, Traversal, Traverser, TraversalStrategy
 from gremlin_python.structure.graph import Edge, Property, Vertex, VertexProperty, Path
+from gremlin_python.structure.io.util import SymbolUtil
 
 # When we fall back to a superclass's serializer, we iterate over this map.
 # We want that iteration order to be consistent, so we use an OrderedDict,
@@ -58,14 +58,14 @@ class GraphSONUtil(object):
     VALUE_KEY = "@value"
 
     @classmethod
-    def typedValue(cls, type_name, value, prefix="g"):
-        out = {cls.TYPE_KEY: cls.formatType(prefix, type_name)}
+    def typed_value(cls, type_name, value, prefix="g"):
+        out = {cls.TYPE_KEY: cls.format_type(prefix, type_name)}
         if value is not None:
             out[cls.VALUE_KEY] = value
         return out
 
     @classmethod
-    def formatType(cls, prefix, type_name):
+    def format_type(cls, prefix, type_name):
         return "%s:%s" % (prefix, type_name)
 
 
@@ -79,11 +79,11 @@ class GraphSONWriter(object):
         if serializer_map:
             self.serializers.update(serializer_map)
 
-    def writeObject(self, objectData):
+    def write_object(self, objectData):
         # to JSON
-        return json.dumps(self.toDict(objectData), separators=(',', ':'))
+        return json.dumps(self.to_dict(objectData), separators=(',', ':'))
 
-    def toDict(self, obj):
+    def to_dict(self, obj):
         """
         Encodes python objects in GraphSON type-tagged dict values
         """
@@ -96,9 +96,9 @@ class GraphSONWriter(object):
 
         # list and map are treated as normal json objs (could be isolated serializers)
         if isinstance(obj, (list, set)):
-            return [self.toDict(o) for o in obj]
+            return [self.to_dict(o) for o in obj]
         elif isinstance(obj, dict):
-            return dict((self.toDict(k), self.toDict(v)) for k, v in obj.items())
+            return dict((self.to_dict(k), self.to_dict(v)) for k, v in obj.items())
         else:
             return obj
 
@@ -112,11 +112,11 @@ class GraphSONReader(object):
         if deserializer_map:
             self.deserializers.update(deserializer_map)
 
-    def readObject(self, jsonData):
+    def read_object(self, json_data):
         # from JSON
-        return self.toObject(json.loads(jsonData))
+        return self.to_object(json.loads(json_data))
 
-    def toObject(self, obj):
+    def to_object(self, obj):
         """
         Unpacks GraphSON type-tagged dict values into objects mapped in self.deserializers
         """
@@ -126,27 +126,17 @@ class GraphSONReader(object):
             except KeyError:
                 pass
             # list and map are treated as normal json objs (could be isolated deserializers)
-            return dict((self.toObject(k), self.toObject(v)) for k, v in obj.items())
+            return dict((self.to_object(k), self.to_object(v)) for k, v in obj.items())
         elif isinstance(obj, list):
-            return [self.toObject(o) for o in obj]
+            return [self.to_object(o) for o in obj]
         else:
             return obj
 
 
-@six.add_metaclass(GraphSONTypeType)
-class _GraphSONTypeIO(object):
+class _GraphSONTypeIO(object, metaclass=GraphSONTypeType):
     python_type = None
     graphson_type = None
 
-    symbolMap = {"global_": "global", "as_": "as", "in_": "in", "and_": "and",
-                 "or_": "or", "is_": "is", "not_": "not", "from_": "from",
-                 "set_": "set", "list_": "list", "all_": "all", "with_": "with",
-                 "filter_": "filter", "id_": "id", "max_": "max", "min_": "min", "sum_": "sum"}
-
-    @classmethod
-    def unmangleKeyword(cls, symbol):
-        return cls.symbolMap.get(symbol, symbol)
-
     def dictify(self, obj, writer):
         raise NotImplementedError()
 
@@ -160,7 +150,7 @@ class _BytecodeSerializer(_GraphSONTypeIO):
         out = []
         for instruction in instructions:
             inst = [instruction[0]]
-            inst.extend(writer.toDict(arg) for arg in instruction[1:])
+            inst.extend(writer.to_dict(arg) for arg in instruction[1:])
             out.append(inst)
         return out
 
@@ -173,7 +163,7 @@ class _BytecodeSerializer(_GraphSONTypeIO):
             out["source"] = cls._dictify_instructions(bytecode.source_instructions, writer)
         if bytecode.step_instructions:
             out["step"] = cls._dictify_instructions(bytecode.step_instructions, writer)
-        return GraphSONUtil.typedValue("Bytecode", out)
+        return GraphSONUtil.typed_value("Bytecode", out)
 
 class TraversalSerializer(_BytecodeSerializer):
     python_type = Traversal
@@ -189,8 +179,8 @@ class VertexSerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, vertex, writer):
-        return GraphSONUtil.typedValue("Vertex", {"id": writer.toDict(vertex.id),
-                                                  "label": writer.toDict(vertex.label)})
+        return GraphSONUtil.typed_value("Vertex", {"id": writer.to_dict(vertex.id),
+                                                   "label": writer.to_dict(vertex.label)})
 
 
 class EdgeSerializer(_GraphSONTypeIO):
@@ -199,12 +189,12 @@ class EdgeSerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, edge, writer):
-        return GraphSONUtil.typedValue("Edge", {"id": writer.toDict(edge.id),
-                                                "outV": writer.toDict(edge.outV.id),
-                                                "outVLabel": writer.toDict(edge.outV.label),
-                                                "label": writer.toDict(edge.label),
-                                                "inV": writer.toDict(edge.inV.id),
-                                                "inVLabel": writer.toDict(edge.inV.label)})
+        return GraphSONUtil.typed_value("Edge", {"id": writer.to_dict(edge.id),
+                                                 "outV": writer.to_dict(edge.outV.id),
+                                                 "outVLabel": writer.to_dict(edge.outV.label),
+                                                 "label": writer.to_dict(edge.label),
+                                                 "inV": writer.to_dict(edge.inV.id),
+                                                 "inVLabel": writer.to_dict(edge.inV.label)})
 
 
 class VertexPropertySerializer(_GraphSONTypeIO):
@@ -213,10 +203,10 @@ class VertexPropertySerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, vertex_property, writer):
-        return GraphSONUtil.typedValue("VertexProperty", {"id": writer.toDict(vertex_property.id),
-                                                          "label": writer.toDict(vertex_property.label),
-                                                          "value": writer.toDict(vertex_property.value),
-                                                          "vertex": writer.toDict(vertex_property.vertex.id)})
+        return GraphSONUtil.typed_value("VertexProperty", {"id": writer.to_dict(vertex_property.id),
+                                                           "label": writer.to_dict(vertex_property.label),
+                                                           "value": writer.to_dict(vertex_property.value),
+                                                           "vertex": writer.to_dict(vertex_property.vertex.id)})
 
 
 class PropertySerializer(_GraphSONTypeIO):
@@ -225,20 +215,20 @@ class PropertySerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, property, writer):
-        elementDict = writer.toDict(property.element)
-        if elementDict is not None:
-            valueDict = elementDict["@value"]
-            if "outVLabel" in valueDict:
-                del valueDict["outVLabel"]
-            if "inVLabel" in valueDict:
-                del valueDict["inVLabel"]
-            if "properties" in valueDict:
-                del valueDict["properties"]
-            if "value" in valueDict:
-                del valueDict["value"]
-        return GraphSONUtil.typedValue("Property", {"key": writer.toDict(property.key),
-                                                    "value": writer.toDict(property.value),
-                                                    "element": elementDict})
+        element_dict = writer.to_dict(property.element)
+        if element_dict is not None:
+            value_dict = element_dict["@value"]
+            if "outVLabel" in value_dict:
+                del value_dict["outVLabel"]
+            if "inVLabel" in value_dict:
+                del value_dict["inVLabel"]
+            if "properties" in value_dict:
+                del value_dict["properties"]
+            if "value" in value_dict:
+                del value_dict["value"]
+        return GraphSONUtil.typed_value("Property", {"key": writer.to_dict(property.key),
+                                                    "value": writer.to_dict(property.value),
+                                                    "element": element_dict})
 
 
 class TraversalStrategySerializer(_GraphSONTypeIO):
@@ -246,7 +236,7 @@ class TraversalStrategySerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, strategy, writer):
-        return GraphSONUtil.typedValue(strategy.strategy_name, writer.toDict(strategy.configuration))
+        return GraphSONUtil.typed_value(strategy.strategy_name, writer.to_dict(strategy.configuration))
 
 
 class TraverserIO(_GraphSONTypeIO):
@@ -255,13 +245,13 @@ class TraverserIO(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, traverser, writer):
-        return GraphSONUtil.typedValue("Traverser", {"value": writer.toDict(traverser.object),
-                                                     "bulk": writer.toDict(traverser.bulk)})
+        return GraphSONUtil.typed_value("Traverser", {"value": writer.to_dict(traverser.object),
+                                                     "bulk": writer.to_dict(traverser.bulk)})
 
     @classmethod
     def objectify(cls, d, reader):
-        return Traverser(reader.toObject(d["value"]),
-                         reader.toObject(d["bulk"]))
+        return Traverser(reader.to_object(d["value"]),
+                         reader.to_object(d["bulk"]))
 
 
 class EnumSerializer(_GraphSONTypeIO):
@@ -269,8 +259,8 @@ class EnumSerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, enum, _):
-        return GraphSONUtil.typedValue(cls.unmangleKeyword(type(enum).__name__),
-                                       cls.unmangleKeyword(str(enum.name)))
+        return GraphSONUtil.typed_value(SymbolUtil.to_camel_case(type(enum).__name__),
+                                        SymbolUtil.to_camel_case(str(enum.name)))
 
 
 class PSerializer(_GraphSONTypeIO):
@@ -279,9 +269,9 @@ class PSerializer(_GraphSONTypeIO):
     @classmethod
     def dictify(cls, p, writer):
         out = {"predicate": p.operator,
-               "value": [writer.toDict(p.value), writer.toDict(p.other)] if p.other is not None else
-               writer.toDict(p.value)}
-        return GraphSONUtil.typedValue("P", out)
+               "value": [writer.to_dict(p.value), writer.to_dict(p.other)] if p.other is not None else
+               writer.to_dict(p.value)}
+        return GraphSONUtil.typed_value("P", out)
 
 
 class TextPSerializer(_GraphSONTypeIO):
@@ -290,9 +280,9 @@ class TextPSerializer(_GraphSONTypeIO):
     @classmethod
     def dictify(cls, p, writer):
         out = {"predicate": p.operator,
-               "value": [writer.toDict(p.value), writer.toDict(p.other)] if p.other is not None else
-               writer.toDict(p.value)}
-        return GraphSONUtil.typedValue("TextP", out)
+               "value": [writer.to_dict(p.value), writer.to_dict(p.other)] if p.other is not None else
+               writer.to_dict(p.value)}
+        return GraphSONUtil.typed_value("TextP", out)
 
 
 class BindingSerializer(_GraphSONTypeIO):
@@ -301,8 +291,8 @@ class BindingSerializer(_GraphSONTypeIO):
     @classmethod
     def dictify(cls, binding, writer):
         out = {"key": binding.key,
-               "value": writer.toDict(binding.value)}
-        return GraphSONUtil.typedValue("Binding", out)
+               "value": writer.to_dict(binding.value)}
+        return GraphSONUtil.typed_value("Binding", out)
 
 
 class LambdaSerializer(_GraphSONTypeIO):
@@ -323,7 +313,7 @@ class LambdaSerializer(_GraphSONTypeIO):
         else:
             out["arguments"] = -1
 
-        return GraphSONUtil.typedValue("Lambda", out)
+        return GraphSONUtil.typed_value("Lambda", out)
 
 
 class TypeSerializer(_GraphSONTypeIO):
@@ -331,7 +321,7 @@ class TypeSerializer(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, typ, writer):
-        return writer.toDict(typ())
+        return writer.to_dict(typ())
 
 
 class UUIDIO(_GraphSONTypeIO):
@@ -341,7 +331,7 @@ class UUIDIO(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, obj, writer):
-        return GraphSONUtil.typedValue(cls.graphson_base_type, str(obj))
+        return GraphSONUtil.typed_value(cls.graphson_base_type, str(obj))
 
     @classmethod
     def objectify(cls, d, reader):
@@ -362,7 +352,7 @@ class DateIO(_GraphSONTypeIO):
             pts = calendar.timegm(obj.timetuple()) * 1e3
 
         ts = int(round(pts))
-        return GraphSONUtil.typedValue(cls.graphson_base_type, ts)
+        return GraphSONUtil.typed_value(cls.graphson_base_type, ts)
 
     @classmethod
     def objectify(cls, ts, reader):
@@ -383,7 +373,7 @@ class TimestampIO(_GraphSONTypeIO):
         # Java timestamp expects milliseconds integer
         # Have to use int because of legacy Python
         ts = int(round(obj * 1000))
-        return GraphSONUtil.typedValue(cls.graphson_base_type, ts)
+        return GraphSONUtil.typed_value(cls.graphson_base_type, ts)
 
     @classmethod
     def objectify(cls, ts, reader):
@@ -396,7 +386,7 @@ class _NumberIO(_GraphSONTypeIO):
     def dictify(cls, n, writer):
         if isinstance(n, bool):  # because isinstance(False, int) and isinstance(True, int)
             return n
-        return GraphSONUtil.typedValue(cls.graphson_base_type, n)
+        return GraphSONUtil.typed_value(cls.graphson_base_type, n)
 
     @classmethod
     def objectify(cls, v, _):
@@ -413,13 +403,13 @@ class FloatIO(_NumberIO):
         if isinstance(n, bool):  # because isinstance(False, int) and isinstance(True, int)
             return n
         elif math.isnan(n):
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "NaN")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "NaN")
         elif math.isinf(n) and n > 0:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "Infinity")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "Infinity")
         elif math.isinf(n) and n < 0:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "-Infinity")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "-Infinity")
         else:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, n)
+            return GraphSONUtil.typed_value(cls.graphson_base_type, n)
 
     @classmethod
     def objectify(cls, v, _):
@@ -444,13 +434,13 @@ class BigDecimalIO(_NumberIO):
         if isinstance(n, bool):  # because isinstance(False, int) and isinstance(True, int)
             return n
         elif math.isnan(n):
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "NaN", "gx")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "NaN", "gx")
         elif math.isinf(n) and n > 0:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "Infinity", "gx")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "Infinity", "gx")
         elif math.isinf(n) and n < 0:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, "-Infinity", "gx")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, "-Infinity", "gx")
         else:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, str(n), "gx")
+            return GraphSONUtil.typed_value(cls.graphson_base_type, str(n), "gx")
 
     @classmethod
     def objectify(cls, v, _):
@@ -481,9 +471,9 @@ class Int64IO(_NumberIO):
         if isinstance(n, bool):
             return n
         elif n < -9223372036854775808 or n > 9223372036854775807:
-            return GraphSONUtil.typedValue("BigInteger", str(n), "gx")
+            return GraphSONUtil.typed_value("BigInteger", str(n), "gx")
         else:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, n)
+            return GraphSONUtil.typed_value(cls.graphson_base_type, n)
 
 
 class BigIntegerIO(Int64IO):
@@ -501,11 +491,11 @@ class Int32IO(Int64IO):
         if isinstance(n, bool):
             return n
         elif n < -9223372036854775808 or n > 9223372036854775807:
-            return GraphSONUtil.typedValue("BigInteger", str(n), "gx")
+            return GraphSONUtil.typed_value("BigInteger", str(n), "gx")
         elif n < -2147483648 or n > 2147483647:
-            return GraphSONUtil.typedValue("Int64", n)
+            return GraphSONUtil.typed_value("Int64", n)
         else:
-            return GraphSONUtil.typedValue(cls.graphson_base_type, n)
+            return GraphSONUtil.typed_value(cls.graphson_base_type, n)
 
 
 class ByteIO(_NumberIO):
@@ -517,7 +507,7 @@ class ByteIO(_NumberIO):
     def dictify(cls, n, writer):
         if isinstance(n, bool):  # because isinstance(False, int) and isinstance(True, int)
             return n
-        return GraphSONUtil.typedValue(cls.graphson_base_type, n, "gx")
+        return GraphSONUtil.typed_value(cls.graphson_base_type, n, "gx")
 
     @classmethod
     def objectify(cls, v, _):
@@ -531,7 +521,7 @@ class ByteBufferIO(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, n, writer):
-        return GraphSONUtil.typedValue(cls.graphson_base_type, "".join(chr(x) for x in n), "gx")
+        return GraphSONUtil.typed_value(cls.graphson_base_type, "".join(chr(x) for x in n), "gx")
 
     @classmethod
     def objectify(cls, v, _):
@@ -545,7 +535,7 @@ class CharIO(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, n, writer):
-        return GraphSONUtil.typedValue(cls.graphson_base_type, n, "gx")
+        return GraphSONUtil.typed_value(cls.graphson_base_type, n, "gx")
 
     @classmethod
     def objectify(cls, v, _):
@@ -559,7 +549,7 @@ class DurationIO(_GraphSONTypeIO):
 
     @classmethod
     def dictify(cls, n, writer):
-        return GraphSONUtil.typedValue(cls.graphson_base_type, duration_isoformat(n), "gx")
+        return GraphSONUtil.typed_value(cls.graphson_base_type, duration_isoformat(n), "gx")
 
     @classmethod
     def objectify(cls, v, _):
@@ -571,7 +561,7 @@ class VertexDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        return Vertex(reader.toObject(d["id"]), d.get("label", "vertex"))
+        return Vertex(reader.to_object(d["id"]), d.get("label", "vertex"))
 
 
 class EdgeDeserializer(_GraphSONTypeIO):
@@ -579,10 +569,10 @@ class EdgeDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        return Edge(reader.toObject(d["id"]),
-                    Vertex(reader.toObject(d["outV"]), d.get("outVLabel", "vertex")),
+        return Edge(reader.to_object(d["id"]),
+                    Vertex(reader.to_object(d["outV"]), d.get("outVLabel", "vertex")),
                     d.get("label", "edge"),
-                    Vertex(reader.toObject(d["inV"]), d.get("inVLabel", "vertex")))
+                    Vertex(reader.to_object(d["inV"]), d.get("inVLabel", "vertex")))
 
 
 class VertexPropertyDeserializer(_GraphSONTypeIO):
@@ -590,10 +580,10 @@ class VertexPropertyDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        vertex = Vertex(reader.toObject(d.get("vertex"))) if "vertex" in d else None
-        return VertexProperty(reader.toObject(d["id"]),
+        vertex = Vertex(reader.to_object(d.get("vertex"))) if "vertex" in d else None
+        return VertexProperty(reader.to_object(d["id"]),
                               d["label"],
-                              reader.toObject(d["value"]),
+                              reader.to_object(d["value"]),
                               vertex)
 
 
@@ -602,8 +592,8 @@ class PropertyDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        element = reader.toObject(d["element"]) if "element" in d else None
-        return Property(d["key"], reader.toObject(d["value"]), element)
+        element = reader.to_object(d["element"]) if "element" in d else None
+        return Property(d["key"], reader.to_object(d["value"]), element)
 
 
 class PathDeserializer(_GraphSONTypeIO):
@@ -612,7 +602,7 @@ class PathDeserializer(_GraphSONTypeIO):
     @classmethod
     def objectify(cls, d, reader):
         labels = [set(label) for label in d["labels"]]
-        objects = [reader.toObject(o) for o in d["objects"]]
+        objects = [reader.to_object(o) for o in d["objects"]]
         return Path(labels, objects)
 
 
@@ -621,7 +611,7 @@ class TraversalMetricsDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        return reader.toObject(d)
+        return reader.to_object(d)
 
 
 class MetricsDeserializer(_GraphSONTypeIO):
@@ -629,4 +619,4 @@ class MetricsDeserializer(_GraphSONTypeIO):
 
     @classmethod
     def objectify(cls, d, reader):
-        return reader.toObject(d)
+        return reader.to_object(d)
